from setuptools import find_packages
from setuptools import setup

setup(
    name='myst-client',
    version='0.0.1',
    author='Sean MacPherson',
    author_email='smacpherson@myst.ai',
    description='coming soon',
    long_description='coming soon',
    long_description_content_type='text/plain',
    url='https://myst.ai',
    packages=find_packages(),
)
